@@ -3,8 +3,8 @@
 # Author          : Johan Vromans
 # Created On      : Sat Oct 15 23:36:51 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Fri Oct  6 22:13:25 2006
-# Update Count    : 63
+# Last Modified On: Sat Dec 16 17:36:20 2006
+# Update Count    : 72
 # Status          : Unknown, Use with caution!
 
 my $RCS_Id = '$Id$ ';
@@ -39,6 +39,23 @@ sub adm_open {
     1;
 }
 
+sub check_bsk_nr {
+    my ($self, $opts) = @_;
+    my $bsk_nr = $opts->{boekstuk};
+    my $bky = $opts->{boekjaar};
+    $bky = $dbh->adm("bky") unless defined($bky);
+    my $dbk = $opts->{dagboek};
+    my $rr = $dbh->do("SELECT count(*) FROM Boekstukken".
+		      " WHERE bsk_nr = ? AND bsk_dbk_id = ? AND bsk_bky = ?",
+		      $bsk_nr, $dbk, $bky);
+    return 1 if defined($rr) && $rr->[0] == 0;
+    warn("?".__x("Boekstuk {bsk} is reeds in gebruik",
+		 bsk => join(":",
+			     $dbh->lookup($dbk, qw(Dagboeken dbk_id dbk_desc)),
+			     $bsk_nr))."\n");
+    return;
+}
+
 sub bsk_nr {
     my ($self, $opts) = @_;
     my $bsk_nr;
@@ -48,6 +65,7 @@ sub bsk_nr {
 	    warn("?"._T("Het boekstuknummer moet een geheel getal (volgnummer) zijn")."\n");
 	    return;
 	}
+	return unless $self->check_bsk_nr($opts);
 	my $t = $prev ? "0" : $opts->{dagboek};
 	$dbh->set_sequence("bsk_nr_${t}_seq", $bsk_nr+1)
 #	  if $dbh->get_sequence("bsk_nr_${t}_seq", "noincr") < $bsk_nr;
@@ -59,6 +77,8 @@ sub bsk_nr {
     }
     else {
 	$bsk_nr = $dbh->get_sequence("bsk_nr_".$opts->{dagboek}."_seq");
+	$opts->{boekstuk} = $bsk_nr;
+	return unless $self->check_bsk_nr($opts);
     }
     $bsk_nr;
 }
@@ -219,7 +239,7 @@ sub journalise {
 		 " WHERE dbk_id = ?", $bsk_dbk_id)};
     my $sth = $::dbh->sql_exec("SELECT bsr_nr, bsr_date, ".
 			     "bsr_desc, bsr_amount, bsr_btw_class, bsr_btw_id, ".
-			     "bsr_btw_acc, bsr_type, bsr_acc_id, bsr_rel_code ".
+			     "bsr_btw_acc, bsr_type, bsr_acc_id, bsr_rel_code, bsr_dbk_id".
 			     " FROM Boekstukregels".
 			     " WHERE bsr_bsk_id = ?", $bsk_id);
 
@@ -230,7 +250,7 @@ sub journalise {
 
     while ( $rr = $sth->fetchrow_arrayref ) {
 	my ($bsr_nr, $bsr_date, $bsr_desc, $bsr_amount, $bsr_btw_class,
-	    $bsr_btw_id, $bsr_btw_acc, $bsr_type, $bsr_acc_id, $bsr_rel_code) = @$rr;
+	    $bsr_btw_id, $bsr_btw_acc, $bsr_type, $bsr_acc_id, $bsr_rel_code, $bsr_rel_dbk) = @$rr;
 	my $bsr_bsk_id = $bsk_id;
 	my $btw = 0;
 	my $amt = $bsr_amount;
@@ -247,26 +267,26 @@ sub journalise {
 	push(@$ret, [$bsk_date, $bsk_dbk_id, $bsk_id, $bsr_date, $nr++,
 		     $bsr_acc_id,
 		     $bsr_amount - $btw, undef, $bsr_desc,
-		     $bsr_type ? $bsr_rel_code : undef]);
+		     $bsr_type ? ($bsr_rel_code, $bsr_rel_dbk) : (undef, undef)]);
 	push(@$ret, [$bsk_date,  $bsk_dbk_id, $bsk_id, $bsr_date, $nr++,
 		     $bsr_btw_acc,
 		     $btw, undef, "BTW ".$bsr_desc,
-		     undef]) if $btw;
+		     undef, undef]) if $btw;
     }
 
     if ( $dbk_acc_id ) {
 	if ( $dbkdcsplit ) {
 	    push(@$ret, [$bsk_date,  $bsk_dbk_id, $bsk_id, $bsk_date, $nr++, $dbk_acc_id,
-			 -$tot, -$dtot, $bsk_desc, undef]);
+			 -$tot, -$dtot, $bsk_desc, undef, undef]);
 	}
 	else {
 	    push(@$ret, [$bsk_date,  $bsk_dbk_id, $bsk_id, $bsk_date, $nr++, $dbk_acc_id,
-			 -$tot, undef, $bsk_desc, undef]);
+			 -$tot, undef, $bsk_desc, undef, undef]);
 	}
     }
 
     unshift(@$ret, [$bsk_date, $bsk_dbk_id, $bsk_id, $bsk_date, 0, undef,
-		    undef, undef, $bsk_desc, undef]);
+		    undef, undef, $bsk_desc, undef, undef]);
 
     $ret;
 }
