@@ -1,10 +1,10 @@
 # Report.pm -- Report tools
-# RCS Info        : $Id: Report.pm,v 1.3 2006/03/03 21:27:11 jv Exp $
+# RCS Info        : $Id$
 # Author          : Johan Vromans
 # Created On      : Mon Nov 14 21:46:04 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Feb 23 15:29:50 2006
-# Update Count    : 35
+# Last Modified On: Sat Jun  3 11:51:53 2006
+# Update Count    : 41
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -16,14 +16,14 @@ package EB::Report;
 use strict;
 use warnings;
 use EB;
-use EB::Finance;
+use EB::Format qw(numfmt);
 use EB::Report::GenBase;
 
 my $trace = 0;
 
 sub GetTAccountsBal {
     shift;
-    my ($end) = @_;
+    my ($end, $inc) = @_;
 
     # balans(r, t) = balans(r, t0) + sum(journaal, r, t0..t) + sum(boekjaarbalans, r, t' < t)
 
@@ -36,11 +36,13 @@ sub GetTAccountsBal {
 		   "acc_ibalance,acc_ibalance AS acc_balance,acc_struct".
 		   " FROM Accounts")->finish;
 
+    return "TAccounts" unless defined $end;
+
     # sum(journaal, r, t0..t)
     my $sth = $dbh->sql_exec("SELECT jnl_acc_id,acc_balance,SUM(jnl_amount)".
 			     " FROM Journal,TAccounts".
 			     " WHERE acc_id = jnl_acc_id".
-			     " AND jnl_date <= ?".
+			     " AND jnl_date ".($inc ? "<" : "<=")." ?".
 			     " GROUP BY jnl_acc_id,acc_balance,acc_ibalance",
 			     $end);
 
@@ -59,7 +61,7 @@ sub GetTAccountsBal {
     # sum(boekjaarbalans, r, t' < t)
     $sth = $dbh->sql_exec("SELECT bkb_acc_id, bkb_balance".
 			  " FROM Boekjaarbalans".
-			  " WHERE bkb_end < ?", $end);
+			  " WHERE bkb_end ".($inc ? "<=" : "<")." ?", $end);
     while ( my $rr = $sth->fetchrow_arrayref ) {
 	my ($acc_id, $acc_balance) = @$rr;
 	warn("!".__x("Balansrekening {acct}, saldo aangepast met {exp}",
