@@ -1,11 +1,11 @@
 #!/usr/bin/perl -w
-my $RCS_Id = '$Id: BTWAangifte.pm,v 1.32 2006/03/06 15:46:43 jv Exp $ ';
+my $RCS_Id = '$Id$ ';
 
 # Author          : Johan Vromans
 # Created On      : Tue Jul 19 19:01:33 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Mon Mar  6 11:15:41 2006
-# Update Count    : 465
+# Last Modified On: Fri Aug 11 11:59:05 2006
+# Update Count    : 472
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -20,7 +20,8 @@ package EB::Report::BTWAangifte;
 use strict;
 
 use EB;
-use EB::Finance;
+use EB::Format;
+use EB::Booking;		# for norm_btw()
 
 use POSIX qw(floor ceil);
 
@@ -345,7 +346,7 @@ sub collect {
 	if ( $btw_id && $btw_acc ) {
 	    # Bepaal tariefgroep en splits bedrag uit.
 	    $btg_id = $dbh->lookup($btw_id, qw(BTWTabel btw_id btw_tariefgroep));
-	    my $a = EB::Finance::norm_btw($amt, $btw_id);
+	    my $a = EB::Booking::->norm_btw($amt, $btw_id);
 	    $amt = $a->[0] - ($btw = $a->[1]); # ex BTW
 	}
 
@@ -497,8 +498,8 @@ sub report {
 		$self->{compat_periode} ? __x("Periode: {per}",
 					      per => $self->{compat_periode})
 					: __x("Periode: {from} t/m {to}",
-					      from => $rep->{per_begin},
-					      to   => $rep->{per_end}));
+					      from => datefmt_full($rep->{per_begin}),
+					      to   => datefmt_full($rep->{per_end})));
 
     # Binnenland
     $rep->outline('H1', "Binnenland");
@@ -634,7 +635,12 @@ sub kleine_ondernemers {
     return 0 if $amount < 0;
 
     # Formule lijkt linds 1995 ongwijzigd, alleen de bedragen veranderen.
-    my %mmtab = ( 2005 => [ 1345, 1883 ] );
+    my %mmtab = ( 2002 => [ 1345, 1883 ],
+		  2003 => [ 1345, 1883 ],
+		  2004 => [ 1345, 1883 ],
+		  2005 => [ 1345, 1883 ],
+		  2006 => [ 1345, 1883 ],
+		);
 
     return unless exists $mmtab{$year};
 
@@ -652,6 +658,8 @@ package EB::Report::BTWAangifte::Text;
 
 use strict;
 use EB;
+use EB::Format qw($amount_width);
+
 use base qw(EB::Report::GenBase);
 
 sub new {
@@ -678,7 +686,7 @@ sub outline {
 	return;
     }
 
-    my $w = $EB::Finance::amount_width + 1;
+    my $w = $amount_width + 1;
     $self->{fh}->printf("%-5s%-40s%${w}s%${w}s\n",
 			$tag0, $tag1,
 			defined($sub) ? $sub : "",
