@@ -1,10 +1,10 @@
 # Html.pm -- HTML backend for BTWAangifte
-# RCS Info        : $Id: Html.pm,v 1.9 2006/01/22 16:43:44 jv Exp $
+# RCS Info        : $Id$
 # Author          : Johan Vromans
 # Created On      : Wed Sep 14 14:51:19 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Fri Jan 20 21:59:45 2006
-# Update Count    : 28
+# Last Modified On: Fri Jun  2 15:33:15 2006
+# Update Count    : 36
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -16,6 +16,7 @@ package EB::Report::BTWAangifte::Html;
 
 use strict;
 use EB;
+use EB::Format qw(datefmt_full);
 
 use base qw(EB::Report::GenBase);
 
@@ -72,9 +73,35 @@ sub start {
     $self->{fh}->print
       ("<html>\n",
        "<head>\n",
-       "<title>", html($t1), "</title>\n",
-       '<link rel="stylesheet" href="css/', $self->{style} || $reptype, '.css">', "\n",
-       "</head>\n",
+       "<title>", html($t1), "</title>\n");
+
+    # This is copied from EB::Report::Reporter::Html.
+    # MUST BE INTEGRATED (LATER).
+    require EB::Report::Reporter::Html;
+    if ( my $style = $self->{style} || $reptype ) {
+	if ( $style =~ /\W/ ) {
+	    print {$self->{fh}}
+	      ('<link rel="stylesheet" href="', $style, '">', "\n");
+	}
+	elsif ( defined $self->{_cssdir} ) {
+	    print {$self->{fh}}
+	      ('<link rel="stylesheet" href="', $self->{_cssdir},
+	       $style, '.css">', "\n");
+	}
+	elsif ( my $css = findlib("css/".$style.".css") ) {
+	    print {$self->{fh}} ('<style type="text/css">', "\n");
+	    EB::Report::Reporter::Html::copy_style($self->{fh}, $css);
+	    print {$self->{fh}} ('</style>', "\n");
+	}
+	else {
+	    print {$self->{fh}} ("<!-- ",
+				 __x("Geen stylesheet voor {style}",
+				     style => $style), " -->\n");
+	}
+    }
+
+    print {$self->{fh}}
+      ("</head>\n",
        "<body>\n",
        "<p class=\"title\">", html($t1), "</p>\n",
        "<p class=\"subtitle\">", html($adm), "</br>\n",
@@ -98,7 +125,7 @@ sub finish {
 
     $self->{fh}->print("<p class=\"footer\">",
 		       __x("Overzicht aangemaakt op {date} door <a href=\"{url}\">{ident}</a>",
-			   ident => $ident, date => $now, url => $EB::url), "</p>\n");
+			   ident => $ident, date => datefmt_full($now), url => $EB::url), "</p>\n");
 
     $self->{fh}->print("</body>\n",
 		       "</html>\n");
