@@ -13,8 +13,8 @@ package EB::Report::Grootboek;
 # Author          : Johan Vromans
 # Created On      : Wed Jul 27 11:58:52 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Mon Oct 16 18:40:49 2006
-# Update Count    : 282
+# Last Modified On: Tue Oct 24 15:11:51 2006
+# Update Count    : 283
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -64,6 +64,8 @@ sub perform {
 
     $rep->start(_T("Grootboek"));
 
+    $dbh->begin_work;
+
     my $table = EB::Report->GetTAccountsAll($begin, $end);
 
     my $ah = $dbh->sql_exec("SELECT acc_id,acc_desc,acc_ibalance,acc_balres".
